"""Autogenerated API"""
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module

log = logging.getLogger(__name__)


@register_command(
    extending=("pdns", "v3", "seen"),
    module=argus_cli_module
)
def exists_records_of_tlp_levels(
    query: str,
    tlp: str = None,
    ignoreOwnRecords: bool = True,
    json: bool = True,
    verify: bool = True,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
  ) -> dict:
    """Search against PassiveDNS and return true if matching records are found (DEV)
    
    :param str query: Search by query, can be IP, not subnet, or domain
    :param list tlp: Search by TLP
    :param bool ignoreOwnRecords: Whether to ignore user's customer's own records, defaults to true
    :raises AuthenticationFailedException: on 401
    :raises ResourceLimitExceededException: on 402
    :raises AccessDeniedException: on 403
    :raises ValidationFailedException: on 412
    :raises ArgusException: on other status codes
    
    :returns dictionary translated from JSON
    """
    from os import getenv
    from requests import get
    from argus_api._validators import validate_http_response
    
    from argus_cli.settings import settings
    
    url = "{}/pdns/v3/{query}/seen".format(
        server_url or settings["api"]["api_url"],
        ignoreOwnRecords=ignoreOwnRecords,
        query=query,
        tlp=tlp
    )
    headers = {
        'User-Agent': 'ArgusToolbelt/',
        'content': 'application/json'
    }

    if not apiKey and "api_key" in settings["api"]:
        apiKey = settings["api"]["api_key"]

    if apiKey:
        headers["Argus-API-Key"] = apiKey
    elif authentication and isinstance(authentication, dict):
        headers.update(authentication)
    elif callable(authentication):
        headers.update(authentication(url))

    body = {}

    query_parameters = {}
    # Only send ignoreOwnRecords if the argument was provided, dont send null values
    if ignoreOwnRecords is not None:
        query_parameters.update({"ignoreOwnRecords": ignoreOwnRecords})
    # Only send tlp if the argument was provided, dont send null values
    if tlp is not None:
        query_parameters.update({"tlp": tlp})

    log.debug("GET %s (headers: %s, body: %s)" % (url, str(headers), str(body) or ""))

    response = get(
        url,
        params=query_parameters or None,
        verify=getenv('REQUESTS_CA_BUNDLE', verify),
        headers=headers
    )

    validate_http_response(response)
    return response.json()

